@@ -5,8 +5,6 @@ function(x, ...){
 	formula <- as.formula(Reduce(paste, deparse(formula)))
 	fit.survival <- coxph(formula, data = x$data)
 	pos <- attr(terms.formula(formula, specials = c("pspline")),"specials")$pspline - 1
-	termplot(fit.survival, terms = pos, se = TRUE, ylabs = paste("f(",x$cat.var,")"))
-	for(i in x$results$cutpoints) {
-		abline(v = i, lty = 2)
-	}
+	termplot(fit.survival, terms = pos, se = TRUE, ylabs = paste0("f(",x$cat.var,")"))
+	abline(v = x$results$cutpoints, lty = 2)
 }
